# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Miscellaneous

Package implementing the checker for miscellaneous issues.

### Modules

MiscellaneousChecker | Module implementing a checker for miscellaneous checks.
MiscellaneousDefaults | Module implementing complex defaults for the miscellaneous checker.
eradicate | Removes commented-out Python code.
translations | Module implementing message translations for the code style plugin messages (miscellaneous part).